@@ -140,7 +140,7 @@
     <message>
         <location filename="src/opt/cooktimer/cooktimer" line="557"/>
         <source>Apart from the obvious functions and settings, there are some not so easily spotted:</source>
-        <translation type="unfinished">Naast de vanzelfsprekende functies en instellingen, zijn er een aantal niet zo makkelijk te herkennen:</translation>
+        <translation type="unfinished">Naast de vanzelfsprekende functies en instellingen, is er een aantal niet zo makkelijk te herkennen:</translation>
     </message>
     <message>
         <location filename="src/opt/cooktimer/cooktimer" line="559"/>
